==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-core/FrameworkInterface/SundanceDerivSet.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#ifndef SUNDANCE_DERIVSET_H
#define SUNDANCE_DERIVSET_H



#include "SundanceDefs.hpp"
#include "SundanceMultipleDeriv.hpp"
#include "SundanceSet.hpp"

#ifndef DOXYGEN_DEVELOPER_ONLY



namespace SundanceCore
{
  using namespace SundanceUtils;
  namespace Internal
    {

      /**
       * DerivSet is a set of multiple derivatives, sorted by 
       * increasing differentiation order.
       *
       * The sorting is important because we should evaluate derivatives
       * of products in decreasing order of differentiation order.
       */
      class DerivSet : public SundanceUtils::Set<MultipleDeriv,
        increasingOrder<MultipleDeriv> >
        {
        public:
          /** Construct an empty set of functional derivatives */
          DerivSet();

        };
    }
}

namespace Teuchos
{
  using namespace SundanceUtils;
  using namespace SundanceCore::Internal;
  using namespace SundanceCore;
  inline string toString(const SundanceCore::Internal::DerivSet& d)
  {
    return d.toString();
  }
}


#endif /* DOXYGEN_DEVELOPER_ONLY */
#endif

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-core/FrameworkInterface/SundanceDerivSet.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#ifndef SUNDANCE_DERIVSET_H
#define SUNDANCE_DERIVSET_H



#include "SundanceDefs.hpp"
#include "SundanceMultipleDeriv.hpp"
#include "SundanceSet.hpp"


namespace SundanceCore
{
using namespace SundanceUtils;
/**
 * DerivSet is a set of multiple derivatives, sorted by 
 * increasing differentiation order.
 *
 * The sorting is important because we should evaluate derivatives
 * of products in decreasing order of differentiation order.
 */
class DerivSet : public SundanceUtils::Set<MultipleDeriv,
                                           increasingOrder<MultipleDeriv> >
{
public:
  /** Construct an empty set of functional derivatives */
  DerivSet();

};
}

namespace Teuchos
{
using namespace SundanceUtils;
using namespace SundanceCore;
inline string toString(const SundanceCore::DerivSet& d)
{
  return d.toString();
}
}


#endif
